# kipjak

![PyPI - License](https://img.shields.io/pypi/l/kipjak)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kipjak)
![PyPI - Version](https://img.shields.io/pypi/v/kipjak)
![PyPI - Coverage](https://img.shields.io/badge/coverage-75%25-brightgreen)
![PyPI - Integration](https://img.shields.io/badge/integration-passing-cyan)

---

Concurrency via multithreading, multiprocessing and multihosting.

---

* Concurrency with clarity
* Cookbook of multithreading, multiprocessing and multihosting solutions
* Load distribution across threads, processes and hosts
* Self-regulating services that push back under heavy load
* Child processes as private, loadable libraries
* Definition and execution of process groups
* Foreground or background execution
* Networking without network addresses
* RPC or RESTful APIs
